from datetime import datetime

from .. import Provider as CompanyProvider


def calculate_checksum(value: str) -> str:
    factors = [3, 7, 2, 4, 10, 3, 5, 9, 4, 6, 8][-len(value) :]
    check_sum = 0
    for number, factor in zip(value, factors):
        check_sum += int(number) * factor

    return str((check_sum % 11) % 10)


def calculate_snils_checksum(numbers: str) -> str:
    checksum = sum(int(v) * (9 - i) for i, v in enumerate(numbers)) % 101
    return "%02d" % (checksum if checksum < 100 else 0)


class Provider(CompanyProvider):
    formats = (
        "{{company_prefix}} «{{last_name}}»",
        "{{company_prefix}} «{{last_name}} {{last_name}}»",
        "{{company_prefix}} «{{last_name}}-{{last_name}}»",
        "{{company_prefix}} «{{last_name}}, {{last_name}} и {{last_name}}»",
        "{{last_name}} {{company_suffix}}",
        "{{large_company}}",
    )

    company_prefixes = (
        "РАО",
        "АО",
        "ИП",
        "НПО",
        "ЗАО",
        "ООО",
        "ОАО",
    )

    company_suffixes = (
        "Инк",
        "Инкорпорэйтед",
        "и партнеры",
        "Групп",
        "Лтд",
        "Лимитед",
    )

    # Source: https://www.rbc.ru/rbc500/
    large_companies = (
        "Газпром",
        "ЛУКОЙЛ",
        "Роснефть",
        "Сбербанк России",
        "Российские железные дороги",
        "Ростех",
        "Сургутнефтегаз",
        "X5 Retail Group",
        "ВТБ",
        "Магнит",
        "САФМАР",
        "Росатом",
        "Российские сети",
        "Интер РАО",
        "Транснефть",
        "Татнефть",
        "НОВАТЭК",
        "Евраз",
        "АФК Система",
        "En +",
        "НЛМК",
        "Норникель",
        "ГК Мегаполис",
        "Газпромбанк",
        "Русал",
        "Аэрофлот — Российские авиалинии",
        "Сибур Холдинг",
        "Северсталь",
        "СУЭК",
        "ММК",
        "Группа УГМК",
        "Мобильные телесистемы",
        "Металлоинвест",
        "Лента",
        "Объединенная авиастроительная корпорация",
        "РусГидро",
        "Сахалин Энерджи",
        "Т Плюс",
        "Группа М.Видео-Эльдорадо",
        "Еврохим",
        "ВымпелКом",
        "Банковский холдинг Альфа-банка",
        "Объединенная судостроительная корпорация",
        "МегаФон",
        "Ростелеком",
        "ТМК",
        "Славнефть",
        "Тойота Мотор (Toyota)",
        "Мечел",
        "Автотор холдинг",
        "Стройгазмонтаж",
        "Дж.Т.И. Россия (JTI)",
        "Торговая сеть Красное и Белое",
        "АК Алроса",
        "Дикси Групп",
        "ВЭБ.РФ",
        "ФМСМ (PMI)",
        "Фольксваген Груп Рус",
        "АвтоВАЗ",
        "Леруа Мерлен Восток (Leroi Merlin)",
        "Ашан (Auchan)",
        "Россельхозбанк",
        "ДНС Групп",
        "ГК ТНС энерго",
        "Протек",
        "Группа компаний ПИК",
        "Объединенная двигателестроительная корпорация",
        "Независимая нефтегазовая компания",
        "Merlion",
        "ФосАгро",
        "КМР и СНГ (KIA)",
        "Катрен",
        "Банк ФК Открытие",
        "Корпорация Тактическое ракетное вооружение",
        "Группа Рольф",
        "ТАИФ-НК",
        "Трансмашхолдинг",
        "Метро Кэш энд Керри (Metro Cash & Carry)",
        "Мостотрест",
        "СОГАЗ",
        "Эппл Рус (Apple)",
        "Арктикгаз",
        "Нижнекамскнефтехим",
        "«Томскнефть» ВНК",
        "Зарубежнефть",
        "ЕвроСибЭнерго",
        "Вертолеты России",
        "Группа ГАЗ",
        "Почта России",
        "МУМТ (BAT)",
        "Стройтранснефтегаз",
        "КамАЗ",
        "ФК Пульс",
        "Полюс",
        "Хендэ Мотор СНГ (Hyundai)",
        "S7 Group",
        "Ямал СПГ",
        "Группа Содружество",
        "ЧТПЗ",
        "Иркутская нефтяная компания",
        "Русснефть",
        "Национальная компьютерная корпорация",
        "Мерседес-Бенц Рус (Mercedes-Benz)",
        "Русэнергосбыт",
        "ОМК",
        "Уралкалий",
        "ГК Ташир",
        "Компания Газ-Альянс",
        "ФортеИнвест",
        "Группа Мэйджор",
        "Российская электроника",
        "ГК СНС",
        "Сибирский антрацит",
        "Группа О'кей",
        "Мосинжпроект",
        "UCL Holding",
        "Группа Илим",
        "Московский кредитный банк",
        "Группа Синара",
        "Нефтиса",
        "Объединенная компания Связной — Евросеть",
        "Группа ЛСР",
        "Т2 РТК Холдинг",
        "НЗНП",
        "АльфаСтрахование",
        "Ланит",
        "НПК Уралвагонзавод",
        "Рено Россия (Renault)",
        "Удмуртнефть",
        "Нестле Россия (Nestle)",
        "Райффайзенбанк (Raiffeisen)",
        "Техкомпания Хуавэй (Huawei)",
        "КДВ Групп",
        "Яндекс",
        "Мессояханефтегаз",
        "БМВ Русланд Трейдинг (BMW)",
        "Салым Петролеум",
        "Данон  (Danone)",
        "ЮниКредит Банк (UniCredit)",
        "ТД Риф",
        "Мираторг",
        "Группа Волга-Днепр",
        "Вайлдберриз",
        "Московский метрополитен",
        "Полиметалл",
        "Группа РЕСО",
        "Пепсико холдингс",
        "ГК Эфко",
        "СДС-Уголь",
        "ЛокоТех",
        "ГК Автомир",
        "Совкомбанк",
        "ФСК Лидер",
        "Марс (Mars)",
        "Детский мир",
        "Группа НПФ Благосостояние",
        "Госкорпорация по ОрВД",
        "Трансойл",
        "ОХК Уралхим",
        "Каспийский трубопроводный консорциум-Р",
        "Тинькофф Банк",
        "Fix Price",
        "Промсвязьбанк",
        "Акрон",
        "Спортмастер",
        "Проктер Энд Гэмбл. Дистрибьюторская компания (Procter & Gamble)",
        "Eurasia Drilling Company",
        "Группа Черкизово",
        "ИКЕА Дом (INGKA)",
        "Славянск Эко",
        "Корпорация ВСМПО-АВИСМА",
        "Росбанк (Societe General)",
        "Монетка",
        "Стройсервис",
        "ГК Транстехсервис",
        "Совкомфлот",
        "ВСК",
        "СБСВ-Ключавто",
        "Ингосстрах",
        "Сэтл групп",
        "Гиперглобус (Bruch-Beteiligungs)",
        "Технониколь",
        "Металлсервис",
        "Нефтехимсервис",
        "Промышленно-металлургический холдинг",
        "Урало-Сибирская металлургическая компания",
        "Мария-Ра",
        "Globaltrans",
        "Кубанская нефтегазовая компания",
        "Авиакомпания ЮТэйр",
        "НПФ Газфонд пенсионные накопления",
        "Русагро",
        "Л'Этуаль",
        "ЛГ Электроникс Рус (LG)",
        "Каргилл (Cargill)",
        "ВАД",
        "Астон",
        "Уральские авиалинии",
        "Сталепромышленная компания",
        "НИПИ НГ Петон",
        "Бристоль",
        "Уралвтормет",
        "Нефтетранссервис",
        "Казаньоргсинтез",
        "Газпром бурение",
        "ГК Агро-Белогорье",
        "Фортум (Fortum)",
        "ПК Балтика (Carlsbergfondet)",
        "Авилон АГ",
        "Шелл Нефть (Shell)",
        "Юнипро (Uniper)",
        "Технологии машиностроения (Техмаш)",
        "НПК Объединенная вагонная компания",
        "Велесстрой",
        "ТД Интерторг",
        "Юнилевер Русь (Unilever)",
        "Солид-товарные рынки",
        "Вольво Восток (AB Volvo)",
        "Энел Россия",
        "Марвел КТ",
        "ГК Эталон",
        "Металлокомплект-М",
        "Группа Ренессанс Страхование",
        "Военторг",
        "Nordgold",
        "Сибуглемет",
        "Акционерный банк Россия",
        "ДОМ.РФ",
        "Форд Соллерс Холдинг",
        "ИКЕА Торг (INGKA)",
        "Макдоналдc (McDonald`s)",
        "Кузбасская топливная компания",
        "Хенкель Рус (Henkel)",
        "Дон-Строй Инвест",
        "Главное управление обустройства войск (ГУОВ)",
        "СК Росгосстрах",
        "Кока-Кола Эйчбиси Евразия (Coca-Cola)",
        "Хоум Кредит энд Финанс Банк (PPF)",
        "Гленкор Агро Мзк (Firada)",
        "Mail.Ru Group",
        "Монди СЛПК (Mondi)",
        "НПО Алмаз",
        "ММС Рус (Mitsubishi Motors)",
        "Объединенные кондитеры",
        "Комацу СНГ (Komatsu)",
        "Национальная медиа группа",
        "Агентство по страхованию вкладов (АСВ)",
        "Татэнергосбыт",
        "Куйбышевазот",
        "Азбука вкуса",
        "Трансбункер",
        "Башкирская содовая компания",
        "Инвестнефтетрейд",
        "Inventive Retail Group",
        "Самсунг Электроникс Рус Калуга (Samsung)",
        "Крокус",
        "Гугл (Google)",
        "АСЦ-Холдинг",
        "Новороссийский морской торговый порт",
        "Швабе",
        "Русская медная компания",
        "Евроцемент груп",
        "Мосводоканал",
        "Международный аэропорт Шереметьево",
        "Сегежа",
        "Р-Фарм",
        "Фармстандарт",
        "Ростсельмаш",
        "Транспортная группа FESCO",
        "Компания Адамас",
        "Метафракс",
        "Джонсон & Джонсон (Johnson & Johnson)",
        "Softline",
        "Ягуар ленд ровер",
        "Байер",
        "Эркафарм",
        "Фармперспектива",
        "Банк Уралсиб",
        "ВО Машиноимпорт",
        "Кордиант",
        "Новосталь",
        "ВкусВилл",
        "Л'Ореаль (L'Oreal)",
        "DDS",
        "ТОАЗ",
        "Банк Санкт-Петербург",
        "Группа агропредприятий Ресурс",
        "Ярче!",
        "Ренейссанс Констракшн (Ronesans Holding Anonim Sirketi)",
        "Санофи Россия (Sanofi)",
        "Группа ГМС",
        "Северный ветер",
        "БСС",
        "Скания-Русь (Scania)",
        "ГК Фаворит Моторс",
        "Группа РТК",
        "Фармкомплект",
        "Нокиан Шина (Nokian)",
        "ДСК Автобан",
        "Омега Групп",
        "Квадра",
        "Roust",
        "ГК Невада (Самбери)",
        "Восточный экспресс банк",
        "Верисел-трейдинг",
        "Гознак",
        "Фирма Агрокомплекс им. Ткачева",
        "Банк Русский стандарт",
        "Мазда Мотор Рус (Mazda)",
        "Группа Газфонд",
        "СТД Петрович",
        "Беркс",
        "Кари",
        "Арконик СМЗ",
        "Мон Дэлис (Mondelez)",
        "Комус",
        "Группа Агат",
        "Великолукский мясокомбинат",
        "Верный",
        "СДС Азот",
        "М Фэшн",
        "Белгранкорм-холдинг",
        "Группа Нэфис",
        "ФГ Будущее",
        "Глория Джинс",
        "Билла (Rewe)",
        "Государственная транспортная лизинговая компания",
        "ФК Гранд Капитал",
        "ЭС",
        "Компания Металл Профиль",
        "ГК Орими Трэйд",
        "ГСЛ",
        "Интернешнл Пейпер (International Paper)",
        "Лаборатория Касперского",
        "ПСМА Рус",
        "Аптечная сеть 36,6",
        "Тетра Пак (Tetra Pak)",
        "Центральная пригородная пассажирская компания",
        "Самараэнерго",
        "Азур Эйр",
        "Командор-Холдинг",
        "Белуга Групп",
        "ТД БелАЗ",
        "Мосгортранс",
        "Спар Миддл Волга",
        "Холдинг Транспортные компоненты",
        "Московский аэропорт Домодедово",
        "Рулог (Havi)",
        "Эйч Энд Эм (H&M)",
        "Концерн Автоматика",
        "Татэнерго",
        "Трубная грузовая компания",
        "Комос Групп",
        "Первая тяжеловесная компания",
        "ОМПК",
        "НК Дулисьма",
        "Ачимгаз",
        "Новосибирскэнергосбыт",
        "Компания СИМ-Авто",
        "Ситибанк",
        "Остин",
        "Адидас (Adidas)",
        "Ферреро Руссия (Ferrero)",
        "Пермэнергосбыт",
        "РКК Энергия",
        "Свеза",
        "Росжелдорпроект",
        "Мазда Соллерс Мануфэкчуринг Рус",
        "БСХ Бытовые приборы  (BSH Hausgerate)",
        "Московская биржа ММВБ-РТС",
        "Русэнергоресурс",
        "Компания Луис Дрейфус Восток (Louis Dreyfus)",
        "ЭР-Телеком Холдинг",
        "Соллерс",
        "Объединенная энергетическая компания",
        "Уральские локомотивы",
        "ТМК Чермет",
        "Загорский трубный завод",
        "Элко Рус (Elko)",
        "Архангельский ЦБК",
        "Мособлгаз",
        "ДК Рус",
        "Энергосбытовая компания Восток",
        "ГКНПЦ им. М.В.Хруничева",
        "Металлоторг",
        "Агросила Групп",
        "Ман Трак Энд Бас Рус (Volkswagen)",
        "Петербургский метрополитен",
        "ТГК-2",
        "Концерн Титан-2",
        "Ренейссанс Хэви Индастрис Ronesans Endustri",
        "Бургер Рус (Burger King)",
        "Ozon",
        "Сони Электроникс (Sony)",
        "Продо",
        "Продимекс-Холдинг",
        "АвтоГермес",
        "Railgo",
        "Новотранс",
        "Новикомбанк",
        "Рив Гош",
        "Сибирская горно-металлургическая компания",
        "Сименс (Siemens)",
        "Лига ставок",
        "Банк Ак Барс",
        "Группа Полипластик",
        "Водоканал Санкт-Петербурга",
        "РэйлАльянс",
        "Российская телевизионная и радиовещательная сеть",
        "Зерно-трейд",
        "Ренессанс Кредит",
        "Роберт Бош (Robert Bosch)",
        "ВО Промсырьеимпорт",
        "САП СНГ (SAP)",
        "А Групп",
        "Приосколье",
        "Зара СНГ (Zara)",
        "Модум-транс",
        "Эбботт лэбораториз (Abbott Laboratories)",
        "Группа Магнезит",
        "Газпром автоматизация",
        "Газэнергосервис",
        "Независимая энергосбытовая компания Краснодарского края",
        "Группа ЭПМ",
        "Минудобрения",
        "Либхерр-Русланд (Liebherr)",
        "Восточная техника (Vost-Tech)",
        "Первый канал",
        "ГМК Сплав",
        "ГК Автодилерство",
        "НМЖК",
        "ВГТРК",
        "Неофарм",
        "Роскосмос",
        "Вита Лайн",
        "Краснодарзернопродукт-Экспо",
        "Алкоторг",
        "Красцветмет",
        "Касторама Рус (Castorama)",
        "Деловые линии",
        "ГВСУ по специальным объектам",
        "ПКФ ДиПОС",
        "Восток-Запад",
        "Амурская нефтебаза",
        "Юг Руси",
        "Шнейдер Электрик (Schneider Electric)",
        "Сингента (Chemchina)",
        "Титан",
        "Петропавловск",
        "Фармимэкс",
        "АБ Инбев Эфес (Anheuser-Busch Inbev)",
        "ABI Product",
        "Профитмед",
        "ТД Агроторг",
        "ТЭК СПБ",
        "ТД Ункомтех",
        "ОПХ (Heineken)",
        "ТГК-16",
        "Уральский банк реконструкции и развития",
        "QIWI",
        "СК Согласие",
        "Группа Эссен",
        "Втормет",
        "Эссити (Essity)",
        "Hoff (Домашний интерьер)",
        "Сиско Солюшенз (Cisco)",
        "ВО ЖДТ России",
        "Купишуз (Lamoda)",
        "Делл (Dell)",
        "ПСК",
        "Каменск-Уральский металлургический завод",
        "Аргос",
        "А.П.Р.",
        "ГК 1520",
        "Артис-Агро Экспорт",
        "Луидор",
        "Порше Руссланд (Porsche)",
        "Денцу Эйджис Си Эс (Dentsu)",
        "Эйвон Бьюти Продактс Компани (Avon)",
        "РКЦ Прогресс",
        "Силовые машины",
        "АНГК",
        "Корпорация Гринн",
        "Фаберлик",
        "Сибирская сервисная компания",
        "Банк Возрождение",
        "Отисифарм",
        "Боэс Констракшн (Boes Construction)",
        "Саткинский чугуноплавильный завод",
        "Алтайвагон",
        "ПТК",
        "Щекиноазот",
        "Волгоградэнергосбыт",
        "Русский уголь",
        "Трест КХМ",
        "РМ Рейл",
        "Восточная горнорудная компания",
        "Группа Стройтрансгаз",
        "БАСФ (BASF)",
        "Мерида",
        "Брок-Инвест-Сервис и К",
        "Вирлпул Рус (Whirlpool)",
        "Карелия Палп",
        "Тева (Teva)",
        "Media Direction Group",
        "Якобс Дау Эгбертс Рус (Jacobs Douwe Egberts)",
        "ГК Великан",
        "Август",
        "Транслом",
        "ОТП Банк",
        "РусВинил",
        "Системный оператор Единой энергетической системы",
        "АСР-Углесбыт",
        "ЦЭНКИ",
        "Транстрейдойл",
        "Росморпорт",
        "Газнефтетрэйдинг",
        "Сладковско-Заречное",
        "Кроношпан (Kronoplus)",
        "ТЦ Кунцево Лимитед",
        "СНПХ",
        "Кимберли-Кларк (Kimberly-Clark)",
        "Катерпиллар Евразия (Caterpillar)",
        "Крок инкорпорейтед",
        "Ашинский металлургический завод",
        "Автодом",
        "Международный центр",
        "Мишлен (Michelin)",
        "Картли",
        "БелАЗ-24",
        "Первый завод",
        "ГК ЕКС",
        "Петролеум Трейдинг",
        "Нижфарм (Nidda Midco)",
        "Импэкснефтехим",
        "Вольво Карс (Zhejiang Geely)",
        "Мосметрострой",
        "ТЭК Мосэнерго",
        "Борисхоф 1 (Inchcape)",
        "ГК Титан",
        "ПТК Уголь",
        "Авторусь",
        "Юг-Авто",
        "Нова",
        "Метрострой",
        "Ресурс",
        "Сетевая компания",
        "РЕ Трэйдинг (LPP)",
        "Углетранс",
        "ЭйчПи Инк (HP Inc.)",
        "ТК Шлюмберже (Schlumberger)",
        "ГК Мега-Авто",
        "Корпорация Электросевкавмонтаж",
        "ГК Российские коммунальные системы",
        "Запсибгазпром",
        "Нефтепродукттрейд",
        "Сатурн-Р",
        "Завод имени Дегтярева",
        "Такеда Фармасьютикалс (Takeda Pharmaceutical)",
        "Слата супермаркет",
        "Emex",
        "САМ-МБ",
        "171 Меридиан",
        "Армтек",
        "Центр финансовых технологий",
        "Группа компаний Пионер",
        "АХ Степь",
        "Таграс (ТНГ-Групп)",
        "Fonbet",
        "Сандоз (Sandoz)",
        "Берлин-Хеми А. Менарини (Berlin Chemie)",
        "ГК Агропромкомплектация",
        "МАКС",
        "Компания Трасса",
        "Башкирэнерго",
        "Охрана Росгвардии",
        "Гала-Форм",
        "КРКА Фарма (KRKA)",
        "Максидом",
        "Нефтехимремстрой",
        "Нефтьмагистраль",
        "Авеста Фармацевтика (Baby Dream)",
        "Старттех",
        "Конар",
        "Нортгаз",
        "УГС",
        "АББ (ABB)",
        "Металлстандарт",
        "Балтийская топливная компания",
        "Мострансавто",
        "Аксель-Моторс",
        "Группа компаний МИЦ",
        "ПК Борец",
        "Европа",
        "Сибирская аграрная группа",
        "РТИ",
        "Ферронордик машины (Ferronordic)",
        "Южуралзолото ГК",
        "Прогресс",
        "Юг-Нефтепродукт",
        "Камский кабель",
        "Familia",
        "Транскапиталбанк",
        "А-Ойл",
        "Сибтрейд",
        "МТС-банк",
        "Московская инженерно-строительная компания",
        "Курганмашзавод",
        "Вектрум-К",
        "Морской терминал Тамань",
        "Таркетт Рус (Tarkett)",
        "Несте Санкт-Петербург (Neste)",
        "Ново-Уренгойская газовая компания",
        "Национальная нерудная компания",
        "Октоблу (Decathlon)",
        "Снежная Королева",
        "Новартис Фарма (Novartis)",
        "Магнолия",
        "Техинком",
        "Дочки-Сыночки",
        "Астеллас Фарма",
        "General Fueller",
        "Автозаправочные комплексы Atan",
        "Псковвтормет",
        "Авиакомпания Икар",
    )

    catch_phrase_adj = (
        (
            "Автоматизированный",
            "Автономный",
            "Адаптивный",
            "Амортизированный",
            "Ассимилированный",
            "Безопасный",
            "Бизнес-ориентированный",
            "Взаимовыгодный",
            "Виртуальный",
            "Глубокий",
            "Горизонтальный",
            "Делегируемый",
            "Децентрализованный",
            "Дублируемый",
            "Инверсный",
            "Инновационный",
            "Интегрированный",
            "Интуитивный",
            "Качественный",
            "Клиент-ориентированный",
            "Контролируемый",
            "Концептуальный",
            "Корпоративный",
            "Кросс-платформенный",
            "Межгрупповой",
            "Многогранный",
            "Многоканальный",
            "Многослойный",
            "Многоуровневый",
            "Модернизируемый",
            "Настраиваемый",
            "Новый",
            "Общедоступный",
            "Объектный",
            "Обязательный",
            "Оперативный",
            "Оптимизированный",
            "Опциональный",
            "Организованный",
            "Органичный",
            "Ориентированный",
            "Открытый",
            "Оцифрованный",
            "Переключаемый",
            "Переосмысленный",
            "Переработанный",
            "Перспективный",
            "Полный",
            "Поэтапный",
            "Превентивный",
            "Программируемый",
            "Прогрессивный",
            "Продвинутый",
            "Прочный",
            "Разнообразный",
            "Распределённый",
            "Расширенный",
            "Реализованный",
            "Реконструируемый",
            "Самодостаточный",
            "Сбалансированный",
            "Сетевой",
            "Синхронизированный",
            "Совместимый",
            "Сокращенный",
            "Сосредоточенный",
            "Стабильный",
            "Стратегический",
            "Увеличенный",
            "Удобный",
            "Улучшенный",
            "Улучшенный",
            "Уменьшенный",
            "Универсальный",
            "Управляемый",
            "Устойчивый",
            "Фундаментальный",
            "Функциональный",
            "Цельный",
            "Централизованный",
            "Эксклюзивный",
            "Элегантный",
            "Эргономичный",
        ),
        (
            "аналитический",
            "асимметричный",
            "асинхронный",
            "бездефектный",
            "бескомпромиссный",
            "веб-ориентированный",
            "встречный",
            "вторичный",
            "высокоуровневый",
            "гибкий",
            "гибридный",
            "глобальный",
            "двунаправленный",
            "действенный",
            "динамичный",
            "единообразный",
            "заметный",
            "инструктивный",
            "интерактивный",
            "исполнительный",
            "итернациональный",
            "клиент-серверный",
            "контекстуальный",
            "круглосуточный",
            "логистический",
            "локальный",
            "максимальный",
            "масштабируемый",
            "методичный",
            "многозадачный",
            "мобильный",
            "модульный",
            "мультимедийный",
            "наглядный",
            "направленный",
            "национальный",
            "нейтральный",
            "нестандартный",
            "объектно-ориентированный",
            "однородный",
            "оптимальный",
            "основной",
            "отказостойкий",
            "переходный",
            "последовательный",
            "потенциальный",
            "пошаговый",
            "прибыльный",
            "приоритетный",
            "промежуточный",
            "радикальный",
            "раздвоенный",
            "региональный",
            "связный",
            "систематический",
            "системный",
            "составной",
            "социальный",
            "специализированный",
            "статический",
            "третичный",
            "ультрасовременный",
            "целостный",
            "широкий",
            "широкопрофильный",
            "эвристический",
            "экоцентричный",
            "энергонезависимый",
            "яркий",
        ),
    )

    catch_phrase_nouns_masc = (
        "адаптер",
        "алгоритм",
        "альянс",
        "анализатор",
        "архив",
        "веб-сайт",
        "вызов",
        "графический интерфейс",
        "графический интерфейс пользователя",
        "доступ",
        "инструментарий",
        "интерфейс",
        "инфопосредник",
        "искусственный интеллект",
        "массив",
        "модератор",
        "мониторинг",
        "набор инструкций",
        "параллелизм",
        "подход",
        "портал",
        "прогноз",
        "продукт",
        "проект",
        "протокол",
        "ресурс",
        "системный движок",
        "успех",
        "фреймворк",
        "хаб",
        "эталон",
    )

    catch_phrase_nouns_fem = (
        "архитектура",
        "база данных",
        "база знаний",
        "вероятность",
        "возможность",
        "гибкость",
        "защищенная линия",
        "иерархия",
        "инициатива",
        "инфраструктура",
        "кодировка",
        "конгломерация",
        "концепция",
        "координация",
        "локальная сеть",
        "матрица",
        "методология",
        "миграция",
        "модель",
        "нейронная сеть",
        "парадигма",
        "поддержка",
        "политика",
        "проекция",
        "производительность",
        "прошивка",
        "рабочая группа",
        "реализация",
        "сеть Интранет",
        "сеть Экстранет",
        "служба поддержки",
        "служба техподдержки",
        "способность",
        "стандартизация",
        "стратегия",
        "структура",
        "суперструктура",
        "установка",
        "фокус-группа",
        "функциональность",
        "функция",
        "ценовая структура",
        "эмуляция",
    )

    catch_phrase_nouns_neu = (
        "взаимодействие",
        "групповое программное обеспечение",
        "интернет-решение",
        "использование",
        "межплатформенное программное обеспечение",
        "оборудование",
        "определение",
        "отношение",
        "приложение",
        "программное обеспечение",
        "решение",
        "совершенствование процесса",
        "сотрудничество",
        "управление бюджетом",
        "хранилище данных",
        "шифрование",
        "ядро",
    )

    bsWords = (
        (
            "Адаптация",
            "Визуализация",
            "Включение",
            "Внедрение",
            "Генерация",
            "Инновация",
            "Интеграция",
            "Использование",
            "Итерация",
            "Конструирование",
            "Координация",
            "Культивация",
            "Максимизация",
            "Модернизация",
            "Монетизация",
            "Мотивация",
            "Обеспечение",
            "Объединение",
            "Оптимизация",
            "Освоение",
            "Охват",
            "Оцифровка",
            "Перезагрузка",
            "Переопределение",
            "Переосмысление",
            "Перепрофилирование",
            "Переход",
            "Преображение",
            "Приспособление",
            "Продление",
            "Производство",
            "Развитие",
            "Разворачивание",
            "Разработка",
            "Распределение",
            "Реализация",
            "Революция",
            "Синтез",
            "Синхронизация",
            "Сравнение",
            "Трансформация",
            "Увеличение",
            "Управление",
            "Ускорение",
            "Формирование",
            "Шкалирование",
            "Эксплуатация",
        ),
        (
            "B2B",
            "B2C",
            "активных",
            "безотказных",
            "беспроводных",
            "богатых",
            "веб-ориентированных",
            "вертикальных",
            "виртуальных",
            "глобальных",
            "действенных",
            "динамичных",
            "заказных",
            "индивидуальных",
            "инновационных",
            "интегрированных",
            "интерактивных",
            "интуитивных",
            "концептуальных",
            "корпоративных",
            "критически важных",
            "кроссплатформенных",
            "круглогодичных",
            "круглосуточных",
            "лучших в своём роде",
            "масштабируемых",
            "мультимедийных",
            "наглядных",
            "надежных",
            "онлайн и офлайн",
            "ориентированных на пользователя",
            "открытых",
            "передовых",
            "подробных",
            "популярных",
            "престижных",
            "прибыльных",
            "притягательных",
            "прозрачных",
            "распределённых",
            "распространенных",
            "расширяемых",
            "революционных",
            "сенсационных",
            "серверных",
            "сетевых",
            "соблазнительных",
            "совместных",
            "современных",
            "стандартных",
            "стратегических",
            "ультрасовременных",
            "фронт-энд",
            "целостных",
            "цельных",
            "эффективных",
        ),
        (
            "архитектур",
            "аудиторий",
            "веб-сервисов",
            "взаимодействий",
            "действий",
            "диапазонов",
            "знаний",
            "инициатив",
            "интернет-компаний",
            "интернет-магазинов",
            "интернет-продавцов",
            "интернет-услуг",
            "интерфейсов",
            "инфопосредников",
            "инфраструктур",
            "каналов",
            "методик",
            "метрик",
            "моделей",
            "ниш",
            "областей интереса",
            "отношений",
            "парадигм",
            "партнерств",
            "платформ",
            "пользователей",
            "порталов",
            "приложений",
            "результатов",
            "решений",
            "рынков",
            "сетей",
            "систем",
            "систем снабжения",
            "сообществ",
            "схем",
            "технологий",
            "функций",
        ),
    )

    def catch_phrase(self) -> str:
        """
        :example: 'Адаптивный и масштабируемый графический интерфейс'
        """
        noun: str = self.random_element(
            self.catch_phrase_nouns_masc + self.catch_phrase_nouns_fem + self.catch_phrase_nouns_neu
        )
        adj_first: str = self.random_element(self.catch_phrase_adj[0])
        adj_second: str = self.random_element(self.catch_phrase_adj[1])
        if noun in self.catch_phrase_nouns_fem:
            adj_first = adj_first[:-2] + "ая"
            adj_second = adj_second[:-2] + "ая"
        elif noun in self.catch_phrase_nouns_neu:
            adj_first = adj_first[:-2] + "ое"
            adj_second = adj_second[:-2] + "ое"
        return adj_first + " и " + adj_second + " " + noun

    def large_company(self) -> str:
        """
        :example: 'АвтоВАЗ'
        """
        return self.random_element(self.large_companies)

    def company_prefix(self) -> str:
        """
        :example: 'ООО'
        """
        return self.random_element(self.company_prefixes)

    def businesses_inn(self) -> str:
        """
        Returns tax identification number for businesses (ru. идентификационный номер налогоплательщика, ИНН).
        """
        region: str = "%02d" % self.random_int(min=1, max=92)
        inspection: str = "%02d" % self.random_int(min=1, max=99)
        tail: str = "%05d" % self.random_int(min=1, max=99999)
        result: str = region + inspection + tail

        return result + calculate_checksum(result)

    def individuals_inn(self) -> str:
        """
        Returns tax identification number for individuals (ru. идентификационный номер налогоплательщика, ИНН).
        """
        region: str = "%02d" % self.random_int(min=1, max=92)
        inspection: str = "%02d" % self.random_int(min=1, max=99)
        tail: str = "%06d" % self.random_int(min=1, max=999999)
        result: str = region + inspection + tail
        result += calculate_checksum(result)

        return result + calculate_checksum(result)

    def businesses_ogrn(self) -> str:
        """
        Returns primary state registration number for businesses
        (ru. основной государственный регистрационный номер, ОГРН).
        """
        sign: str = self.random_element(("1", "5"))
        year: str = "%02d" % self.random_int(min=1, max=datetime.now().year - 2000)
        region: str = "%02d" % self.random_int(min=1, max=92)
        tail: str = "%07d" % self.random_int(min=1, max=9999999)

        result: str = sign + year + region + tail

        return result + str((int(result) % 11) % 10)

    def individuals_ogrn(self) -> str:
        """
        Returns primary state registration number for individuals
        (ru. основной государственный регистрационный номер, ОГРН).
        """
        year: str = "%02d" % self.random_int(min=1, max=datetime.now().year - 2000)
        region: str = "%02d" % self.random_int(min=1, max=92)
        tail: str = "%09d" % self.random_int(min=1, max=999999999)

        result: str = "3" + year + region + tail

        return result + str((int(result) % 13) % 10)

    def kpp(self) -> str:
        """
        Returns tax registration reason code (ru. код причины постановки на учет, КПП).
        """
        region: str = "%02d" % self.random_int(min=1, max=92)
        inspection: str = "%02d" % self.random_int(min=1, max=99)
        reason: str = self.random_element(("01", "43", "44", "45"))
        tail: str = "%03d" % self.random_int(min=1, max=999)

        return region + inspection + reason + tail

    def snils(self) -> str:
        """
        Returns SNILS number (ru. СНИЛС).
        """
        numbers: str = "%09d" % self.random_int(min=1, max=999999999)
        return numbers + calculate_snils_checksum(numbers)



from typing import Any

from ..fr_FR import Provider as FRFRProvider


class Provider(FRFRProvider):
    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)



from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats_male = ("{{first_name_male}} {{last_name}}",)

    formats_female = ("{{first_name_female}} {{last_name}}",)

    formats = formats_male + formats_female

    # Source: https://en.wiktionary.org/wiki/Category:Armenian_male_given_names
    first_names_male = (
        "Սիմոն",
        "Ուիլյամ",
        "Ստեֆան",
        "Ռիչարդ",
        "Ֆիլիպ",
        "Ջոն",
        "Հովիկ",
        "Հենրի",
        "Ջորջ",
        "Գարրի",
        "Ֆելիքս",
        "Լևոն",
        "Դոմինիկ",
        "Դենիս",
        "Դանիել",
        "Կլոդ",
        "Քրիստոֆեր",
        "Չարլի",
        "Կարլ",
        "Բորիս",
        "Բեռնար",
        "Անդրեաս",
        "Ալեքսանդր",
        "Աբրահամ",
        "Աբել",
        "Ահարոն",
        "Օլեգ",
        "Փայլակ",
        "Ցոլակ",
        "Րաֆֆի",
        "Տարոն",
        "Վլադիմիր",
        "Վիկտոր",
        "Վահե",
        "Վախթանգ",
        "Վազգեն",
        "Ստեփան",
        "Սեյրան",
        "Սերգեյ",
        "Ռուդոլֆ",
        "Ռուբեն",
        "Ռոման",
        "Ռոբերտ",
        "Ռաֆայել",
        "Շահեն",
        "Նորայր",
        "Նշան",
        "Նարեկ",
        "Նաիրի",
        "Յուրի",
        "Մուրադ",
        "Մխիթար",
        "Մաքսիմ",
        "Մարկոս",
        "Մանվել",
        "Կարեն",
        "Էդուարդ",
        "Էդգար",
        "Զոհրաբ",
        "Գրիգոր",
        "Գոռ",
        "Գևորգ",
        "Գաբրիել",
        "Արման",
        "Արթուր",
        "Անդրանիկ",
        "Ալբերտ",
        "Ադամ",
        "Աբել",
        "Հովհաննես",
        "Աբիգ",
        "Ավետիք",
        "Ավետիս",
        "Աղասի",
        "Ազատ",
        "Հայկ",
        "Հայկազ",
        "Հակոբ",
        "Համազասպ",
        "Հմայակ",
        "Առաքել",
        "Արամ",
        "Արամազդ",
        "Արգամ",
        "Արգիշտի",
        "Արեգ",
        "Արիստակես",
        "Արմեն",
        "Արմենակ",
        "Արսեն",
        "Արտավազդ",
        "Արտակ",
        "Արտաշես",
        "Արտեմ",
        "Արտուր",
        "Արտուշ",
        "Հարություն",
        "Առուշան",
        "Արշավիր",
        "Արշակ",
        "Ատոմ",
        "Աշոտ",
        "Բաբկեն",
        "Բաղդասար",
        "Բաղիշ",
        "Բաղրամ",
        "Բագրատ",
        "Բարսեղ",
        "Բարխուդար",
        "Վահագն",
        "Վահան",
        "Վաղարշակ",
        "Վահրամ",
        "Վարուժան",
        "Վասակ",
        "Գագիկ",
        "Գալուստ",
        "Գարեգին",
        "Գառնիկ",
        "Գարսևան",
        "Գասպար",
        "Գեղամ",
        "Հրանտ",
        "Գուրգեն",
        "Դավիթ",
        "Դերենիկ",
        "Ջիվան",
        "Եղիշ",
        "Երվանդ",
        "Ժիրայր",
        "Զավեն",
        "Զորի",
        "Զոհրապ",
        "Կիկոս",
        "Կիրակոս",
        "Կորյուն",
        "Մամիկոն",
        "Մարգար",
        "Մհեր",
        "Մելքոն",
        "Մելքում",
        "Մեսրոպ",
        "Մեխակ",
        "Միհրան",
        "Մինաս",
        "Մուշեղ",
        "Ներսես",
        "Նուբար",
        "Օհան",
        "Փանոս",
        "Պարգև",
        "Պարթև",
        "Պարույր",
        "Պատվական",
        "Պետրոս",
        "Պողոս",
        "Սահակ",
        "Սաղաթել",
        "Սանասար",
        "Սարգիս",
        "Սասուն",
        "Սերոբ",
        "Սմբատ",
        "Սպարտակ",
        "Սուքիաս",
        "Սուրեն",
        "Թադևոս",
        "Թաթոս",
        "Թաթուլ",
        "Տիգրան",
        "Թորգոմ",
        "Թորոս",
        "Տրդատ",
        "Հունան",
        "Հուսիկ",
        "Խորեն",
        "Խոսրով",
        "Շավարշ",
        "Շմավոն",
    )

    # Source: https://en.wiktionary.org/wiki/Category:Armenian_female_given_names
    first_names_female = (
        "Ագապի",
        "Աիդա",
        "Ալեքսանդրա",
        "Ալինա",
        "Ալիսա",
        "Ալվարդ",
        "Ալլա",
        "Անիտա",
        "Ամալյա",
        "Անահիտ",
        "Անաստասիա",
        "Անժելա",
        "Անգելինա",
        "Անի",
        "Անյա",
        "Աննա",
        "Անտոնինա",
        "Անուշ",
        "Աստղիկ",
        "Արաքսյա",
        "Արևիկ",
        "Արմինե",
        "Արմենուհի",
        "Արփինե",
        "Բարբարա",
        "Բեթի",
        "Բելլա",
        "Բրիժիտ",
        "Բրիջիտ",
        "Գաբրիելլա",
        "Գայանե",
        "Գյուլնարա",
        "Գոհար",
        "Գրետա",
        "Դանիելլա",
        "Դիանա",
        "Դինա",
        "Ելենա",
        "Եվա",
        "Եվգինե",
        "Երանուհի",
        "Զարուհի",
        "Էլեն",
        "Էլիզա",
        "Էլինա",
        "Էմիլիա",
        "Էմմա",
        "Էրիկա",
        "Էվելինա",
        "Թագուհի",
        "Թամարա",
        "Թեհմինե",
        "Թերեզա",
        "Թինա",
        "Ժաքլին",
        "Ժաննա",
        "Իզաբելլա",
        "Ինգա",
        "Ինեսա",
        "Իննա",
        "Իրինա",
        "Լալա",
        "Լառա",
        "Լարիսա",
        "Լաուրա",
        "Լեյլա",
        "Լենա",
        "Լիա",
        "Լիանա",
        "Լիդա",
        "Լիզա",
        "Լիլիթ",
        "Լուսինե",
        "Լուիզա",
        "Ծովինար",
        "Կարինե",
        "Կարոլին",
        "Կասանդրա",
        "Կիրա",
        "Կլարա",
        "Հայկուհի",
        "Հասմիկ",
        "Հեղինե",
        "Հերմինե",
        "Հիլդա",
        "Հռիփսիմե",
        "Հրաչուհի",
        "Մագդա",
        "Մանե",
        "Մարգարիտա",
        "Մարթա",
        "Մարիամ",
        "Մարինե",
        "Մարիա",
        "Մարիաննա",
        "Մելանյա",
        "Մելինե",
        "Միլենա",
        "Մերի",
        "Մոնիկա",
        "Նազելի",
        "Նաիրա",
        "Նանա",
        "Նանե",
        "Նատաշա",
        "Նարե",
        "Նարինե",
        "Նելլի",
        "Նինա",
        "Նոննա",
        "Նորա",
        "Նվարդ",
        "Նունե",
        "Շահանե",
        "Շուշանիկ",
        "Պատրիսիա",
        "Ջեմմա",
        "Ջեյն",
        "Ջեսիկա",
        "Ջուլիետա",
        "Ռաիսա",
        "Ռեբեկա",
        "Ռիմա",
        "Ռիտա",
        "Ռուզան",
        "Սաթենիկ",
        "Սառա",
        "Սեդա",
        "Սեսիլիա",
        "Սիլվա",
        "Սիրարփի",
        "Սյուզաննա",
        "Սոնա",
        "Սոֆյա",
        "Սվետլանա",
        "Ստելլա",
        "Սուսաննա",
        "Վերոնիկա",
        "Վիկտորյա",
        "Վիոլետա",
        "Տաթևիկ",
        "Քիմ",
        "Քնարիկ",
        "Քրիստինե",
        "Օլգա",
        "Օվսաննա",
        "Օֆելյա",
        "Ֆլորա",
        "Ֆրիդա",
    )

    first_names = first_names_male + first_names_female

    # Source: https://en.wiktionary.org/wiki/Category:Armenian_surnames
    last_names = (
        "Աբազյան",
        "Աբաղյան",
        "Աբաղյանց",
        "Աբամելիքյան",
        "Աբաշյան",
        "Աբաջանյան",
        "Աբաջյան",
        "Աբասյան",
        "Աբգարյան",
        "Աբդալյան",
        "Աբդոյան",
        "Աբեթնակյան",
        "Աբելանց",
        "Աբելյան",
        "Աբեղյան",
        "Աբեշյան",
        "Աբեսալոմյանց",
        "Աբթեքյան",
        "Աբիսալոմյան",
        "Աբիսողոմոնյան",
        "Աբոյան",
        "Աբովյան",
        "Աբուջանյան",
        "Աբուսեֆյան",
        "Աբրահամյան",
        "Աբրոյան",
        "Ագիլյան",
        "Ագիշյան",
        "Ագլինցյան",
        "Ագշեհիրյան",
        "Ագոզյան",
        "Ագուլյան",
        "Ագուջյան",
        "Ագրալյան",
        "Ագրակլյան",
        "Ագրամազյան",
        "Ագրապյան",
        "Ագրիպասյան",
        "Ագրյան",
        "Ադաբաշյան",
        "Ադաթուրյան",
        "Ադալյան",
        "Ադամյան",
        "Ադամյանց",
        "Ադանալյան",
        "Ադանելյան",
        "Ադանյան",
        "Ադաջյան",
        "Ադելյան",
        "Ադեյան",
        "Ադիբեկ-Մելիքյան",
        "Ադիբեկյան",
        "Ադիգյոզալյան",
        "Ադիգոզյան",
        "Ադիլխանյան",
        "Ադիլյան",
        "Ադիխանյան",
        "Ադիմզալյան",
        "Ադիյան",
        "Ադիշյան",
        "Ադլխանյան",
        "Ադյան",
        "Ադոյան",
        "Ադոնց",
        "Ադուլյան",
        "Ադունց",
        "Ադրունի",
        "Ազաբյան",
        "Ազանյան",
        "Ազատիկյան",
        "Ազատխանյան",
        "Ազատյան",
        "Ազատյանց",
        "Ազարամյան",
        "Ազարբեկյան",
        "Ազարիկյան",
        "Ազարյան",
        "Ազարումյան",
        "Ազբեկյան",
        "Ազգալդյան",
        "Ազգալդրյան",
        "Ազգելդյան",
        "Ազգուլյան",
        "Ազդարյան",
        "Ազիզբեկյան",
        "Ազիզխանյան",
        "Ազիզյան",
        "Ազիլազյան",
        "Ազիկյան",
        "Ազիրյան",
        "Ազյան",
        "Ազնավուրյան",
        "Ազոյան",
        "Ազուլյան",
        "Ազրյան",
        "Ազրոյան",
        "Աթաբահյան",
        "Աթաբեկյան",
        "Աթաբեկյանց",
        "Աթագյուլյան",
        "Աթալարյան",
        "Աթալյան",
        "Աթալյանց",
        "Աթախանյան",
        "Աթամանյան",
        "Աթամյան",
        "Աթայան",
        "Աթանագինյան",
        "Աթանասյան",
        "Աթանեսյան",
        "Աթանոսյան",
        "Աթաշյան",
        "Աթաջյան",
        "Աթասյան",
        "Աթասունց",
        "Աթարբեկյան",
        "Աթարյան",
        "Աթաքյան",
        "Աթբաշյան",
        "Աթեճյան",
        "Աթեշյան",
        "Աթերզյան",
        "Աթինիզյան",
        "Աթինյան",
        "Աթլոյան",
        "Աթմաճյան",
        "Աթմաջյան",
        "Աթյան",
        "Աթոյան",
        "Աթոռակալյան",
        "Աթումյան",
        "Աթչյան",
        "Աթքյան",
        "Աժանջյան",
        "Աժդահարյան",
        "Աժդարյան",
        "Աժդերհանյան",
        "Աժտեհանյան",
        "Աժտերխանյան",
        "Աժտիկյան",
        "Ալաբաշյան",
        "Ալաբեկյան",
        "Ալաբերկյան",
        "Ալաբերճյան",
        "Ալագյոզյան",
        "Ալաջաջյան",
        "Ալավերդյան",
        "Ալեքսանյան",
        "Ալոյան",
        "Աղաբաբյան",
        "Աղաբեկյան",
        "Աղաջանյան",
        "Աղասյան",
        "Ամարյան",
        "Ամիրբեկյան",
        "Ամիրխանյան",
        "Այվազյան",
        "Անանյան",
        "Անդրեասյան",
        "Անղալադյան",
        "Անոփյան",
        "Անտոնյան",
        "Առաքելյան",
        "Առուստամյան",
        "Ասատրյան",
        "Ասլանյան",
        "Աստվածատրյան",
        "Ավագյան",
        "Ավդալյան",
        "Ավետիսյան",
        "Ավոյան",
        "Ավչյան",
        "Ատրյան",
        "Արեգյան",
        "Արեշյան",
        "Արզումանյան",
        "Արծրունի",
        "Բաբալյան",
        "Բաբաջանյան",
        "Բաբայան",
        "Բաբուջյան",
        "Բագրատյան",
        "Բագրատունի",
        "Բադալյան",
        "Բադալով",
        "Բադասյան",
        "Բադեյան",
        "Բադիկյան",
        "Բազեյան",
        "Բազունց",
        "Բակունց",
        "Բաղդասարյան",
        "Բարսեղյան",
        "Բեկզադյան",
        "Բեկզադով",
        "Բեկյան",
        "Բեկնազարյան",
        "Բեջանյան",
        "Բերբերյան",
        "Բոյաջյան",
        "Բոստանջյան",
        "Բունիաթյան",
        "Բուռնազյան",
        "Գաբոյան",
        "Գաբուզյան",
        "Գաբրիելյան",
        "Գալաչյան",
        "Գալստյան",
        "Գալդունց",
        "Գալֆայան",
        "Գալոյան",
        "Գասպարյան",
        "Գասպարով",
        "Գավալջյան",
        "Գարասեֆերյան",
        "Գերավետյան",
        "Գզիրյան",
        "Գիլոյան",
        "Գիմիշյան",
        "Գլեչյան",
        "Գյանջեցյան",
        "Գյուլնազարյան",
        "Գյումուշյան",
        "Գնունի",
        "Գրիգորյան",
        "Գուլաքսյան",
        "Գուլումյան",
        "Գևորգյան",
        "Դաբաղյան",
        "Դադալյան",
        "Դադասյան",
        "Դալլաքյան",
        "Դանիելյան",
        "Դարբինյան",
        "Դարչինյան",
        "Դեմուրյան",
        "Դևրիկյան",
        "Դիմաքսյան",
        "Դոդոխյան",
        "Դոլուխանյան",
        "Դոլուխանով",
        "Դոխոլյան",
        "Դոխոյան",
        "Դոխոյանց",
        "Դովլաթբեկյան",
        "Դովլաթյան",
        "Դուդուկչյան",
        "Դուզճակատչյան",
        "Դուվալյան",
        "Եգանյան",
        "Եգորյան",
        "Եղիազարյան",
        "Եղնուկյան",
        "Ենգիբարյան",
        "Ենգիբարով",
        "Ենգոյան",
        "Ենիգոմեշյան",
        "Ենոքյան",
        "Եսայան",
        "Երեմյան",
        "Երիբեկյան",
        "Երկանյան",
        "Եփրեմյան",
        "Զադոյան",
        "Զազյան",
        "Զանազանյան",
        "Զավրիյան",
        "Զավարյան",
        "Զատիկյան",
        "Զարգարյան",
        "Զարյան",
        "Զարուբյան",
        "Զաքարյան",
        "Զաքյան",
        "Զաքոյան",
        "Զելվեյան",
        "Զեյթունցյան",
        "Զեյնալյան",
        "Զոհրաբյան",
        "Զոլյան",
        "Զուռնաչյան",
        "Զուրաբյան",
        "Էլբակյան",
        "Էլոյան",
        "Էլչիբեկյան",
        "Էնֆիաջյան",
        "Էսկիբաշյան",
        "Ըրղաթբաշյան",
        "Թադևոսյան",
        "Թաթուլյան",
        "Թաթունց",
        "Թամազյան",
        "Թաշչյան",
        "Թարաքաջյան",
        "Թառայան",
        "Թերզյան",
        "Թեքեյան",
        "Թովմասյան",
        "Թորգոմյան",
        "Թորոսյան",
        "Թովուլջյան",
        "Թումանյան",
        "Թևոսյան",
        "Ժամագործյան",
        "Ժամկոչյան",
        "Իբրահիմբեկյան",
        "Իգիթբաշյան",
        "Իգիթխանյան",
        "Իգիթյան",
        "Իզմիրյան",
        "Իմաստունյան",
        "Իմեքչյան",
        "Իշլեմեճյան",
        "Իշխանյան",
        "Իշտոյան",
        "Իսաբեկյան",
        "Իսաբեկյանց",
        "Իսահակյան",
        "Իսկանդարյան",
        "Իսրայելյան",
        "Լազարյան",
        "Լազարյանց",
        "Լալայան",
        "Լալայանց",
        "Լամբարյան",
        "Լեմենցյան",
        "Լիպարիտյան",
        "Լպուտյան",
        "Լցկարյան",
        "Լուսպարոնյան",
        "Խազաբաշյան",
        "Խազխազյան",
        "Խալաֆյան",
        "Խալիկյան",
        "Խանբաբյան",
        "Խանզադյան",
        "Խաշմանյան",
        "Խաչատրյան",
        "Խաչատրյանց",
        "Խաչենց",
        "Խաչիկօղլյան",
        "Խառատյան",
        "Խեչանյան",
        "Խզմալյան",
        "Խլղաթյան",
        "Խնկոյան",
        "Խոդիկյան",
        "Խուդոյան",
        "Ծաղիկյան",
        "Ծառուկյան",
        "Ծատուրյան",
        "Ծերունյան",
        "Ծորմոտյան",
        "Ծպնեցյան",
        "Ծուռվիզյան",
        "Կաբակուլակյան",
        "Կաբաղյան",
        "Կաբասկալյան",
        "Կադարջյան",
        "Կալդրիկյան",
        "Կալենց",
        "Կալպակչյան",
        "Կամսարյան",
        "Կամսարյանց",
        "Կայֆեջյան",
        "Կաշեգործյան",
        "Կարագյան",
        "Կարախանյան",
        "Կարամանուկյան",
        "Կարապետյան",
        "Կարճիկյան",
        "Կետիկյան",
        "Կոթողյան",
        "Կոնդախչյան",
        "Կոշկակարյան",
        "Կոստանյան",
        "Կրպեյան",
        "Կույումջանյան",
        "Հալաբյան",
        "Հախվերդյան",
        "Հակոբյան",
        "Համբարձումյան",
        "Հայրապետյան",
        "Հայրբաբամյան",
        "Հայրիկյան",
        "Հատիկյան",
        "Հաջինյան",
        "Հարությունյան",
        "Հովասափյան",
        "Հովհաննիսյան",
        "Հովիվյան",
        "Հովսեփյան",
        "Հովսեփով",
        "Հուրդաջյան",
        "Ձավարյան",
        "Ձիթողցյան",
        "Ձիլֆուղարյան",
        "Ձկնորսյան",
        "Ձվակերյան",
        "Ղաբզիմալյան",
        "Ղազախեթյան",
        "Ղազանչյան",
        "Ղազարյան",
        "Ղազարով",
        "Ղազինյան",
        "Ղալդունց",
        "Ղալթախչյան",
        "Ղահրամանյան",
        "Ղամբարյան",
        "Ղայլունջյան",
        "Ղայֆեճյան",
        "Ղանդիլյան",
        "Ղասաբյան",
        "Ղասաբօղլյան",
        "Ղափլանյան",
        "Ղոլթաղչյան",
        "Ճալտիկյան",
        "Ճաղարյան",
        "Ճանճապանյան",
        "Ճանսուզյան",
        "Ճապաղջուրյան",
        "Ճգնավորյան",
        "Ճենեպերեքյան",
        "Ճիվասզյան",
        "Ճոճկանյան",
        "Ճուղուրյան",
        "Մադաթյան",
        "Մազմանյան",
        "Մանանդյան",
        "Մանուկյան",
        "Մանվելյան",
        "Մարաշյան",
        "Մարգարյան",
        "Մելիք-Աբրահամյան",
        "Մելիք-Ադամյան",
        "Մելիք-Ասլանյան",
        "Մելիք-Բարխուդարյան",
        "Մելիք-Օհանջանյան",
        "Մեհրաբյան",
        "Միկոյան",
        "Մինասբեկյան",
        "Մինասյան",
        "Միսակյան",
        "Միրզոյան",
        "Միրզոյանց",
        "Միքայելյան",
        "Մխիթարյան",
        "Մնացականյան",
        "Մշեցյան",
        "Մովսիսյան",
        "Մոսինյան",
        "Մսագործյան",
        "Մսրյան",
        "Մուշեղյան",
        "Մուշկամբարյան",
        "Մուսայելյան",
        "Մուրադյան",
        "Յաբլուկյան",
        "Յագուբյան",
        "Յազիչյան",
        "Յաղլիճյան",
        "Յոգուրթչյան",
        "Յուզբաշյան",
        "Յություճյան",
        "Նաբաթյան",
        "Նազարյան",
        "Նալբանդյան",
        "Նալչադյան",
        "Նախշքարյան",
        "Նահապետյան",
        "Ներկարարյան",
        "Ներսեսյան",
        "Ներսիսյան",
        "Նիկողոսյան",
        "Նշանյան",
        "Շաբոյան",
        "Շաբունց",
        "Շագոյան",
        "Շալավասյան",
        "Շահազիզյան",
        "Շահբազյան",
        "Շահինյան",
        "Շահինյանց",
        "Շահնազարյան",
        "Շարաբխանյան",
        "Շաքարյան",
        "Շաքրամանյան",
        "Շելունց",
        "Շուքուրյան",
        "Ոսկանյան",
        "Ոսկերչյան",
        "Չալիկյան",
        "Չալխիֆալակյան",
        "Չալոյան",
        "Չախմախչյան",
        "Չեմեդիկյան",
        "Չեպչյան",
        "Չեքիջյան",
        "Չիբուխչյան",
        "Չիլինգարյան",
        "Չիվչյան",
        "Չոբանյան",
        "Պալյան",
        "Պապայան",
        "Պապիկյան",
        "Պապոյան",
        "Պառավյան",
        "Պարոնիկյան",
        "Պարոնյան",
        "Պարոնյանց",
        "Պարսամյան",
        "Պերեճիկլյան",
        "Պետրոսյան",
        "Պետրոսյանց",
        "Պոզապալյան",
        "Պողոսյան",
        "Պողպատյան",
        "Պռոշյան",
        "Պստիկյան",
        "Ջալալբեկյան",
        "Ջանավարյան",
        "Ջանգիրյան",
        "Ջանիբեկյան",
        "Ջանջուղազյան",
        "Ջանփոլադյան",
        "Ջանունց",
        "Ջերեջյան",
        "Ջիգարխանյան",
        "Ջուլֆիղարյան",
        "Ռաշիդյան",
        "Ռասիմոսյան",
        "Ռևազյան",
        "Ռշտունի",
        "Ռոստոմյան",
        "Ռուբինյան",
        "Ռուստամյան",
        "Ռուստամյանց",
        "Սադոյան",
        "Սաթյան",
        "Սալբաշյան",
        "Սահակյան",
        "Սանթրոսյան",
        "Սանոյան",
        "Սարգսյան",
        "Սարխոյան",
        "Սարոյան",
        "Սիսոյան",
        "Սաֆարյան",
        "Սեմերջյան",
        "Սիմոնյան",
        "Սիրունյան",
        "Սոլախյան",
        "Սողոմոնյան",
        "Ստեփանյան",
        "Սրմաքեշյան",
        "Սուրմելյան",
        "Սուփրիկյան",
        "Սուքիասյան",
        "Վազիգեղցյան",
        "Վահանյան",
        "Վահունի",
        "Վանեցյան",
        "Վանյան",
        "Վարդապետյան",
        "Վարդերեսյան",
        "Վարոսյան",
        "Վարպետյան",
        "Վերանյան",
        "Վրացյան",
        "Տաճատյան",
        "Տասնապետյան",
        "Տարոնցյան",
        "Տեր-Գևորգյան",
        "Տեր-Հովհաննիսյան",
        "Տեր-Ղազարյան",
        "Տեր-Վահանյան",
        "Տոնոյան",
        "Տոպաջիկյան",
        "Տուղրեմաճյան",
        "Ցախկլորյան",
        "Ցիպլեցյան",
        "Ցոլակյան",
        "Ցրտատարյան",
        "Ուզանկիչյան",
        "Ուզունյան",
        "Ութմազյան",
        "Ուլիխանյան",
        "Ուլուբաբյան",
        "Ուստաբաշյան",
        "Ուրֆալյան",
        "Փալանդուզյան",
        "Փախչանյան",
        "Փահլևանյան",
        "Փամբուխչյան",
        "Փամբուկչյան",
        "Փայլաբազյան",
        "Փանոսյան",
        "Փաշայան",
        "Փաշինյան",
        "Փարաջանյան",
        "Փարաքեսիկյան",
        "Փարսադանյան",
        "Փափազյան",
        "Փիլիփոսյան",
        "Փոքրիկյան",
        "Քաթանասյան",
        "Քալանթարյան",
        "Քալաշյան",
        "Քաղցրիկյան",
        "Քարտաշյան",
        "Քափանակցյան",
        "Քեշիշյան",
        "Քեչօղլյան",
        "Քիլարջյան",
        "Քյոսայան",
        "Քոչարյան",
        "Քոչինյան",
        "Քրմոյան",
        "Քրքորյան",
        "Քուշքյան",
        "Օդյան",
        "Օզանյան",
        "Օզնեցյան",
        "Օհանյան",
        "Օրբելյան",
        "Ֆալյան",
        "Ֆահրադյան",
        "Ֆոլյան",
        "Ֆռանգյան",
        "Ֆրանգուլյան",
    )



from .. import Provider as AutomotiveProvider


class Provider(AutomotiveProvider):
    """Implement automotive provider for ``id_ID`` locale."""

    license_formats = (
        "? ### ??",
        "? ### ???",
        "?? ### ??",
        "?? ### ???",
        "? #### ??",
        "? #### ???",
        "?? #### ??",
        "?? #### ???",
    )



from typing import Tuple

from ... import ElementsType
from .. import Provider as CurrencyProvider


class Provider(CurrencyProvider):
    # see full list in Ukrainian @ Wiki
    # https://uk.wikipedia.org/wiki/%D0%9A%D0%BB%D0%B0%D1%81%D0%B8%D1%84%D1%96%D0%BA%D0%B0%D1%86%D1%96%D1%8F_%D0%B2%D0%B0%D0%BB%D1%8E%D1%82_(ISO_4217)#%D0%9F%D0%B5%D1%80%D0%B5%D0%BB%D1%96%D0%BA_%D0%B4%D1%96%D1%8E%D1%87%D0%B8%D1%85_%D0%BA%D0%BE%D0%B4%D1%96%D0%B2
    currencies: ElementsType[Tuple[str, str]] = (
        ("AED", "Дирхам ОАЕ"),
        ("AFN", "Афганістанський афгані"),
        ("ALL", "Албанський лек"),
        ("AMD", "Вірменський драм"),
        ("ANG", "Гульден Нідерландських Антилів"),
        ("AOA", "Ангольська кванза"),
        ("ARS", "Аргентинське песо"),
        ("AUD", "Австралійський долар"),
        ("AWG", "Арубський флорин"),
        ("AZN", "Азербайджанський манат"),
        ("BAM", "Конвертовна марка Боснії і Герцоговини"),
        ("BBD", "Барбадоський долар"),
        ("BDT", "Бангладешська така"),
        ("BGN", "Болгарський лев"),
        ("BHD", "Бахрейнський динар"),
        ("BIF", "Бурундійський франк"),
        ("BMD", "Бермудський долар"),
        ("BND", "Брунейський долар"),
        ("BOB", "Болівійський болівіано"),
        ("BRL", "Бразильський реал"),
        ("BSD", "Багамський долар"),
        ("BTN", "Бутанський нґултрум"),
        ("BWP", "Ботсванська пула"),
        ("BYR", "Білоруський рубль"),
        ("BZD", "Белізький долар"),
        ("CAD", "Канадський долар"),
        ("CDF", "Конголезький франк"),
        ("CHF", "Швейцарський франк"),
        ("CLP", "Чилійське песо"),
        ("CNY", "Китайський юань"),
        ("COP", "Колумбійське песо"),
        ("CRC", "Коста-риканський колон"),
        ("CUP", "Кубинське песо"),
        ("CVE", "Ескудо Кабо-Верде"),
        ("CZK", "Чеська крона"),
        ("DJF", "Джибутійський франк"),
        ("DKK", "Данська крона"),
        ("DOP", "Домініканське песо"),
        ("DZD", "Алжирський динар"),
        ("EGP", "Єгипетський фунт"),
        ("ERN", "Еритрейська накфа"),
        ("ETB", "Ефіопський бир"),
        ("EUR", "Євро"),
        ("FJD", "Фіджійський долар"),
        ("FKP", "Фолклендський фунт"),
        ("GBP", "Фунт стерлінгів"),
        ("GEL", "Грузинський ларі"),
        ("GHS", "Ганський седі"),
        ("GIP", "Ґібралтарський фунт"),
        ("GMD", "Гамбійський даласі"),
        ("GNF", "Гвінейський франк"),
        ("GTQ", "Ґватемальський кетсаль"),
        ("GYD", "Гаянський долар"),
        ("HKD", "Гонконгівський долар"),
        ("HNL", "Гондураська лемпіра"),
        ("HTG", "Ґурд Республіки Гаїті"),
        ("HUF", "Угорський форинт"),
        ("IDR", "Індонезійська рупія"),
        ("ILS", "Новий ізраїльський шекель"),
        ("NIS", "Новий ізраїльський шекель"),
        ("INR", "Індійська рупія"),
        ("IQD", "Іракський динар"),
        ("IRR", "Іранський ріал"),
        ("ISK", "Ісландська крона"),
        ("JMD", "Ямайський долар"),
        ("JOD", "Йорданський динар"),
        ("JPY", "Японська єна"),
        ("KES", "Кенійський шилінг"),
        ("KGS", "Киргизький сом"),
        ("KHR", "Камбоджійський рієль"),
        ("KMF", "Коморський франк"),
        ("KPW", "Північно-корейська вона"),
        ("KRW", "Південно-корейська вона"),
        ("KWD", "Кувейтський динар"),
        ("KYD", "Долар Кайманових островів"),
        ("KZT", "Казахстанський теньґе"),
        ("LAK", "Лаоський кіп"),
        ("LBP", "Ліванський фунт"),
        ("LKR", "Рупія Шрі-Ланки"),
        ("LRD", "Ліберійський долар"),
        ("LSL", "Лоті Королівства Лесото"),
        ("LTL", "Литовська лита"),
        ("LYD", "Лівійський динар"),
        ("MAD", "Марокканський дирхам"),
        ("MDL", "Молдовський лей"),
        ("MGA", "Малагасійський аріарі"),
        ("MKD", "Македонський денар"),
        ("MMK", "М'янмський к'ят"),
        ("MNT", "Монгольський тугрик"),
        ("MOP", "Маканська патака"),
        ("MRO", "Мавританська уґія"),
        ("MUR", "Маврикійська рупія"),
        ("MVR", "Мальдівська руфія"),
        ("MWK", "Малавійська квача"),
        ("MXN", "Мексиканське песо"),
        ("MYR", "Малайзійський рингіт"),
        ("MZN", "Мозамбіцький метикал"),
        ("NAD", "Намібійський долар"),
        ("NGN", "Ніґерійська найра"),
        ("NIO", "Золота кордоба"),
        ("NOK", "Норвезька крона"),
        ("NPR", "Непальська рупія"),
        ("NZD", "Новозеландський долар"),
        ("OMR", "Оманський ріал"),
        ("PAB", "Панамське бальбоа"),
        ("PEN", "Перуанський соль"),
        ("PGK", "Папуановогвинейська кіна"),
        ("PHP", "Філіппінський песо"),
        ("PKR", "Пакистанська рупія"),
        ("PLN", "Польский злотий"),
        ("PYG", "Парагвайський ґуарані"),
        ("QAR", "Катарський ріал"),
        ("RON", "Румунський лей"),
        ("RSD", "Сербський динар"),
        ("RUB", "Російський рубль"),
        ("RWF", "Руандійський франк"),
        ("SAR", "Саудівський ріал"),
        ("SBD", "Долар Соломонових Островів"),
        ("SCR", "Сейшельська рупія"),
        ("SDG", "Суданський фунт"),
        ("SEK", "Шведська крона"),
        ("SGD", "Сінгапурський долар"),
        ("SHP", "Фунт Святої Єлени"),
        ("SLL", "Леоне Сьєрра-Леоне"),
        ("SOS", "Сомалійський шилінг"),
        ("SRD", "Суринамський долар"),
        ("STD", "Добра Сан-Томе і Принсіпі"),
        ("SVC", "Сальвадорський колон"),
        ("SYP", "Сирійський фунт"),
        ("SZL", "Свазілендський ліланґені"),
        ("THB", "Таїландський бат"),
        ("TJS", "Таджицький сомоні"),
        ("TMT", "Туркменський манат"),
        ("TND", "Туніський динар"),
        ("TOP", "Тонґська паанга"),
        ("TRY", "Турецька ліра"),
        ("TTD", "Долар Тринідаду і Тобаго"),
        ("TWD", "Новий тайванський долар"),
        ("TZS", "Танзанійський шилінг"),
        ("UAH", "Українська гривня"),
        ("UGX", "Угандійський шилінг"),
        ("USD", "Долар США"),
        ("UYU", "Уругвайське песо"),
        ("UZS", "Узбецький сум"),
        ("VEF", "Венесуельский болівар"),
        ("VND", "В'єтнамський донг"),
        ("VUV", "Вануатська вану"),
        ("WST", "Самоанська тала"),
        ("XAF", "Центральноафриканський франк"),
        ("XCD", "Східнокарибський долар"),
        ("XDR", "Спеціальні права запозичення"),
        ("XOF", "Західноафриканський франк"),
        ("XPF", "Французький тихоокеанський франк"),
        ("YER", "Єменський ріал"),
        ("ZAR", "Південноафриканський ранд"),
        ("ZMW", "Замбійська квача"),
        ("ZWD", "Зімбабвійський долар"),
    )

    price_formats = ["#,##", "%#,##", "%##,##", "% ###,##", "%# ###,##"]

    def pricetag(self) -> str:
        return self.numerify(self.random_element(self.price_formats)) + "\N{NO-BREAK SPACE}грн."



import string

from .. import Provider as AutomotiveProvider


class Provider(AutomotiveProvider):
    """Implement automotive provider for ``ro_RO`` locale."""

    license_plate_prefix = (
        "AB",
        "AG",
        "AR",
        "B",
        "BC",
        "BH",
        "BN",
        "BR",
        "BT",
        "BV",
        "BZ",
        "CJ",
        "CL",
        "CS",
        "CT",
        "CV",
        "DB",
        "DJ",
        "GJ",
        "GL",
        "GR",
        "HD",
        "HR",
        "IF",
        "IL",
        "IS",
        "MH",
        "MM",
        "MS",
        "NT",
        "OT",
        "PH",
        "SB",
        "SJ",
        "SM",
        "SV",
        "TL",
        "TM",
        "TR",
        "VL",
        "VN",
        "VS",
    )

    license_plate_suffix = (
        "-###-???",
        "-##-???",
    )

    def license_plate(self) -> str:
        """Generate a license plate."""
        prefix: str = self.random_element(self.license_plate_prefix)
        suffix = self.bothify(
            self.random_element(self.license_plate_suffix),
            letters=string.ascii_uppercase,
        )
        return prefix + suffix



from typing import Tuple

from .. import ElementsType
from .. import Provider as CurrencyProvider


class Provider(CurrencyProvider):
    # source: https://www.laenderdaten.info/waehrungen/

    currencies: ElementsType[Tuple[str, str]] = (
        ("AED", "Arabische Dirham"),
        ("AFN", "Afghani"),
        ("ALL", "Albanische Lek"),
        ("AMD", "Armenische Dram"),
        ("ANG", "Antillen Gulden"),
        ("AOA", "Angolanische Kwanza"),
        ("ARS", "Argentinische Peso"),
        ("AUD", "Australische Dollar"),
        ("AWG", "Aruba Florin"),
        ("AZN", "Aserbaidschanische Manat"),
        ("BAM", "Konvertible Mark"),
        ("BBD", "Barbados Dollar"),
        ("BDT", "Bangladeschische Taka"),
        ("BGN", "Bulgarische Lew"),
        ("BHD", "Bahrainische Dinar"),
        ("BIF", "Burundische Franc"),
        ("BMD", "Bermudische Dollar"),
        ("BND", "Brunei Dollar"),
        ("BOB", "Boliviano"),
        ("BRL", "Brasilianische Real"),
        ("BSD", "Bahamas Dollar"),
        ("BTN", "Bhutanisches Ngultrum"),
        ("BWP", "Botswanische Pula"),
        ("BYR", "Belarussische Rubel"),
        ("BZD", "Belize Dollar"),
        ("CAD", "Kanadische Dollar"),
        ("CDF", "Kongolesische Franc"),
        ("CHF", "Schweizer Franken"),
        ("CLP", "Chilenische Peso"),
        ("CNY", "Renminbi Yuán"),
        ("COP", "Kolumbische Peso"),
        ("CRC", "Costa-Rica Colón"),
        ("CUC", "Cuba Peso Convertible"),
        ("CUP", "Kubanische Peso"),
        ("CVE", "Cap Verdische Escudo"),
        ("CZK", "Tschechische Krone"),
        ("DJF", "Dschibuti Franc"),
        ("DKK", "Dänische Krone"),
        ("DOP", "Dominikanische Peso"),
        ("DZD", "Algerische Dinar"),
        ("EGP", "Ägyptische Pfund"),
        ("ERN", "Eritreische Nakfa"),
        ("ETB", "Äthiopische Birr"),
        ("EUR", "Euro"),
        ("FJD", "Fidschi Dollar"),
        ("FKP", "Falkländische Pfund"),
        ("GBP", "Sterling Pfund"),
        ("GEL", "Georgische Lari"),
        ("GGP", "Guernsey Pfund"),
        ("GHS", "Ghanaische Cedi"),
        ("GIP", "Gibraltar Pfund"),
        ("GMD", "Gambische Dalasi"),
        ("GNF", "Guinea Franc"),
        ("GTQ", "Guatemaltekischer Quetzal"),
        ("GYD", "Guyana Dollar"),
        ("HKD", "Hongkong Dollar"),
        ("HNL", "Honduranische Lempira"),
        ("HRK", "Kroatische Kuna"),
        ("HTG", "Haitianische Gourde"),
        ("HUF", "Ungarische Forint"),
        ("IDR", "Indonesische Rupiah"),
        ("ILS", "Israelische Schekel"),
        ("NIS", "Israelische Schekel"),
        ("IMP", "Isle-of-Man Pfund"),
        ("INR", "Indische Rupie"),
        ("IQD", "Irakische Dinar"),
        ("IRR", "Iranische Rial"),
        ("ISK", "Isländische Krone"),
        ("JEP", "Jersey Pfund"),
        ("JMD", "Jamaikanische Dollar"),
        ("JOD", "Jordanische Dinar"),
        ("JPY", "Japanische Yen"),
        ("KES", "Kenianische Schilling"),
        ("KGS", "Kirgisische Som"),
        ("KHR", "Kambodschanische Riel"),
        ("KMF", "Komorische Franc"),
        ("KPW", "Nordkoreanische Won"),
        ("KRW", "Südkoreanische Won"),
        ("KWD", "Kuwaitische Dinar"),
        ("KYD", "Cayman Dollar"),
        ("KZT", "Kasachische Tenge"),
        ("LAK", "Laotische Kip"),
        ("LBP", "Libanesische Pfund"),
        ("LKR", "Sri Lanka Rupie"),
        ("LRD", "Liberianische Dollar"),
        ("LSL", "Lesothische Loti"),
        ("LYD", "Libysche Dinar"),
        ("MAD", "Marokkanische Dirham"),
        ("MDL", "Moldauische Leu"),
        ("MGA", "Madagassische Ariary"),
        ("MKD", "Mazedonische Denar"),
        ("MMK", "Burmesische Kyat"),
        ("MNT", "Mongolische Tögrög"),
        ("MOP", "Macau Pataca"),
        ("MRO", "Mauretanische Ouguiya"),
        ("MUR", "Mauritius Rupie"),
        ("MVR", "Maledivische Rufiyaa"),
        ("MWK", "Malawische Kwacha"),
        ("MXN", "Mexikanische Peso"),
        ("MYR", "Malaysische Ringgit"),
        ("MZN", "Mosambikanische Metical"),
        ("NAD", "Namibische Dollar"),
        ("NGN", "Nigerianische Naira"),
        ("NIO", "Nicaraguanische Córdoba Oro"),
        ("NOK", "Norwegische Krone"),
        ("NPR", "Nepalesische Rupie"),
        ("NZD", "Neuseeländische Dollar"),
        ("OMR", "Omanische Rial"),
        ("PAB", "Panamaische Balboa"),
        ("PEN", "Peruanische Sol"),
        ("PGK", "Papua-neuguineische Kina"),
        ("PHP", "Philippinische Peso"),
        ("PKR", "Pakistanische Rupie"),
        ("PLN", "Polnische Złoty"),
        ("PYG", "Paraguayische Guaraní"),
        ("QAR", "Qatar Riyal"),
        ("RON", "Rumänische Leu"),
        ("RSD", "Serbische Dinar"),
        ("RUB", "Russische Rubel"),
        ("RWF", "Ruandische Franc"),
        ("SAR", "Saudische Riyal"),
        ("SBD", "Salomonische Dollar"),
        ("SCR", "Seychellen Rupie"),
        ("SDG", "Sudanesische Pfund"),
        ("SEK", "Schwedische Krone"),
        ("SGD", "Singapur Dollar"),
        ("SHP", "St.-Helena Pfund"),
        ("SLL", "Sierra-leonische Leone"),
        ("SOS", "Somalische Schilling"),
        ("SPL", "Seborga Luigini"),
        ("SRD", "Surinamische Dollar"),
        ("STD", "São-toméische Dobra"),
        ("SVC", "El-Salvador-Colón"),
        ("SYP", "Syrische Pfund"),
        ("SZL", "Swazi Lilangeni"),
        ("THB", "Thailändische Baht"),
        ("TJS", "Tadschikische Somoni"),
        ("TMT", "Turkmenische Manat"),
        ("TND", "Tunesische Dinar"),
        ("TOP", "Tongaische Pa'anga"),
        ("TRY", "Türkische Lira"),
        ("TTD", "Trinidad und Tobago Dollar"),
        ("TVD", "Tuvalu Dollar"),
        ("TWD", "Neu Taiwanesische Dollar"),
        ("TZS", "Tansanische Schilling"),
        ("UAH", "Ukrainische Hrywnja"),
        ("UGX", "Ugandische Schilling"),
        ("USD", "Amerikanische Dollar"),
        ("UYU", "Uruguayische Peso"),
        ("UZS", "Uzbekische So'm"),
        ("VEF", "Venezuelanische Bolívar"),
        ("VND", "Vietnamesischer Dong"),
        ("VUV", "Vanuatuische Vatu"),
        ("WST", "Samoanische Tala"),
        ("XAF", "Zentralafrikanische CFA-Franc"),
        ("XCD", "Ostkaribische Dollar"),
        ("XDR", "Sonderziehungsrecht"),
        ("XOF", "Westafrikanische CFA-Franc"),
        ("XPF", "Pazifische Franc"),
        ("YER", "Jemenitische Rial"),
        ("ZAR", "Südafrikanische Rand"),
        ("ZMW", "Sambische Kwacha"),
        ("ZWD", "Simbabwe Dollar"),
    )
